================
ETOS Test Runner
================

.. image:: https://img.shields.io/badge/Stage-Sandbox-yellow.svg
  :target: https://github.com/eiffel-community/community/blob/master/PROJECT_LIFECYCLE.md#stage-sandbox

ETOS (Eiffel Test Orchestration System) Test Runner


Description
===========

The ETOS Test Runner is responsible for executing test suites in ETOS.
ETR should, ideally, be executed within a test runner docker container.


Installation
============

   pip install etos_test_runner


Contribute
==========

- Issue Tracker: https://github.com/eiffel-community/etos/issues
- Source Code: https://github.com/eiffel-community/etos-test-runner


Support
=======

If you are having issues, please let us know.
There is a mailing list at: etos-maintainers@googlegroups.com or just write an Issue.
